C /********************************************************************/
C /*     This program calculates dissimilarity coefficients and uses  */
C /* these values to determine analogs to input cores.  For example,  */
C /* if the user has an ocean core and wants to find analogs in the   */
C /* modern data set, then this program will locate analogs.  See the */
C /* user documentation on setting up an input deck.  This program is */
C /* written in VS FORTRAN.  It prompts the user for the deck file    */
C /* which is explained in the printed documentation.                 */
C /*                Written by Philip J. Howell  (3-7-85)             */
C /*                Last modified on March 25, 1991                   */
C /********************************************************************/
      Program Analog88
      Integer     maxD
      Parameter  (maxD = 1200)
      REAL D(maxD),SUM(2),P(45),Q(maxD,45),SIGMA(4,2),MEAN(4,2),
     & BUGSUM,HIGH,LOW,S(45),MAXVAL(4),MINVAL(4),HI(4),XBAR(45),SIM(10)
     & ,SUMXX(45),SUMX(45),PP(45),LO(4),SUMSQR(4,2),
     & QQ(45),DSML(maxD),T(2,maxD),SUMD(4),LAT2(2,maxD),LONG2(2,maxD)
     & ,LATAVG,LATSTD,LONAVG,LONSTD,NLAT2,NLONG2
      INTEGER N,NCORE1,NCORE2,DEPTH,DEPTH2(maxD),FLAG(maxD),Z,NN(45),
     & TAG2,CHOICE,X,F(maxD),TAG1,XX(4),TOP,COUNT,BUGFLG
      CHARACTER*80 FMAT(3),ENVFMT,INFO,FMAT2(3),NAMES(4),SFILE,AFILE,
     & OUT1,OUT2,EFILE
*     CHARACTER*80  DECKFN
      CHARACTER*250 SFMT,AFMT
      CHARACTER*12 CORE,COREID(maxD)
      CHARACTER*8 LAT,LON
C /********************************************************************/
C /* READ IN INFORMATION FROM THE INPUT DECK.  THE VARIABLES ARE:     */
C /*       SFILE = SUBJECT FAUNAL DATA FILE NAME                      */
C /*       AFILE = ANALOG FAUNAL DATA FILE NAME                       */
C /*       EFILE = ENVIRONMENTAL DATA FILE NAME                       */
C /*       OUT1 = OUTPUT FILE NAME FOR MAIN OUTPUT FILE               */
C /*       OUT2 = OUTPUT FILE NAME FOR SECONDARY (SUMMARY) OUTPUT     */
C /*       TAG1 = FLAG TO INDICATE HEADER CARDS IN SUBJECT FILE       */
C /*       TAG2 = FLAG TO INDICATE HEADER CARDS IN ANALOG FILE        */
C /*       CHOICE = THE USER'S CHOICE OF A DISSIMILARITY COEFFICIENT  */
C /*       N = NUMBER OF SPECIES                                      */
C /*       NCORE1 = NUMBER OF CORES IN FIRST INPUT ("SUBJECT" DATA)   */
C /*       NCORE2 = NUMBER OF CORES IN SECOND INPUT ("ANALOG" DATA)   */
C /*       TOP = NUMBER OF TOP ANALOGS TO BE LISTED (5 OR 10)         */
C /*       INFO = RUN INFORMATION AND SPECIFICATIONS                  */
C /*       NAMES = THE NAMES OF THE SPECIES BEING USED                */
C /*       FMAT = FORMAT FOR THE SUBJECT DATA FILE                    */
C /*       FMAT2 = FORMAT FOR THE ANALOG DATA FILE                    */
C /*       ENVFMT = FORMAT OF ENVIRONMENTAL DATA                      */
C /* THEN, READ IN THE VALUES FROM THE ENVIRONMENTAL DATA FILE.       */
C /********************************************************************/

*      WRITE(*,1)
*    1 FORMAT('Please enter the name of the input deck:'/
*     & '(Press RETURN key to default to "Analog Deck".)')
*      READ(*,2) DECKFN
*    2 FORMAT(A80)
*      IF (DECKFN .EQ. ' ') DECKFN='Analog Deck'
*      OPEN(UNIT=8,FILE=DECKFN)

      write(*,'(A)') " "
      write(*,'(A)') "Please select the name of the input deck:"      
      OPEN(UNIT=8,FILE="",STATUS="OLD")
      
      write(*,'(A)') " "
      WRITE(*,3)
    3 FORMAT(/'Please be patient.  The program is executing.')
      READ(8,7) SFILE
      READ(8,7) AFILE
      READ(8,7) EFILE
      READ(8,7) OUT1
      READ(8,7) OUT2
      
      write(*,'(A)') " "
      write(*,'(A)') "Load..."
      write(*,'(A)') SFILE
      write(*,'(A)') AFILE
      write(*,'(A)') EFILE
      
      write(*,'(A)') " "
      write(*,'(A)') "Open..."
      write(*,'(A)') OUT1
      write(*,'(A)') OUT2
      
      READ(8,5) TAG1,TAG2,CHOICE
    5 FORMAT(3I1)
    

      READ(8,6) N,NCORE1,NCORE2,TOP
    6 FORMAT(I2,1X,I3,1X,I4,1X,I2)
      READ(8,7) INFO
      write(*,'(A)') " "
      write(*,'(A)') "Info:"
      write(*,'(A)') INFO
      do i=1,4
        READ(8,7) NAMES(i)
      end do
      do i=1,3  
        READ(8,7) FMAT(i)
      end do  
      do i=1,3  
        READ(8,7) FMAT2(i)
      end do  
      READ(8,7) ENVFMT
      SFMT = FMAT(1) // FMAT(2) // FMAT(3)
      AFMT = FMAT2(1) // FMAT2(2) // FMAT2(3)
    7 FORMAT(A80)
      write(*,'(A)') " "
      write(*,'(A)') "Formats:"
      write(*,'(A)') SFMT
      write(*,'(A)') AFMT
      write(*,'(A)') ENVFMT
      OPEN(10,FILE=SFILE,ACTION='READ')
      OPEN(11,FILE=AFILE,ACTION='READ')
      OPEN(12,FILE=OUT1,STATUS='UNKNOWN',CREATOR='EDIT')
      OPEN(15,FILE=OUT2,STATUS='UNKNOWN',CREATOR='EDIT')
      OPEN(19,FILE=EFILE,ACTION='READ')
      READ(19,ENVFMT) (T(1,J),T(2,J),J=1,NCORE2)
      IF ((TAG1.LT.0).OR.(TAG1.GT.1).OR.(TAG2.GT.1).OR.(TAG2.LT.0)) THEN
         WRITE(12,8)
    8    FORMAT(/'YOU HAVE NOT INDICATED IF THERE ARE HEADER CARDS IN'/
     &           'THE ANALOG OR SUBJECT INPUT FILES.  PLEASE CHECK.'/
     &           '***** HALT EXECUTION')
         GOTO 5000
      END IF
C /********************************************************************/
C /* READ IN THE DATA FROM THE ANALOG FAUNAL DATA FILE.  ONCE THIS IS */
C /* DONE, THE SPECIES THAT ARE SPECIFIED IN THE INPUT DECK ARE       */
C /* CONVERTED TO PROPORTION FORM.  THEN, CALCULATE THE STANDARD      */
C /* DEVIATION OF EACH BUG.  THESE VALUES ARE NEEDED FOR THE SQUARED  */
C /* STANDARDIZED EUCLIDEAN DISTANCE COEFFICIENT.  SHOULD IT OCCUR    */
C /* THAT NO SPECIES ARE IN AN ANALOG CORE, OR AN UNDEFINED STANDARD  */
C /* DEVIATION EXISTS, THEN A MESSAGE IS WRITTEN TO THE OUTPUT FILE   */
C /* AND EXECUTION IS STOPPED.                                        */
C /********************************************************************/
      IF (CHOICE .EQ. 3) THEN
         DO 10 J=1,N
            SUMX(J)=0.0
            SUMXX(J)=0.0
            NN(J)=0
   10    CONTINUE
      END IF
      BUGFLG=0
      DO 24 J=1,NCORE2
         IF (TAG2 .EQ. 0) READ(11,AFMT) COREID(J),(Q(J,L),L=1,N)
         IF (TAG2 .EQ. 1) READ(11,AFMT) COREID(J),(LAT2(K,J),K=1,2),
     &       (LONG2(K,J),K=1,2),DEPTH2(J),(Q(J,L),L=1,N)
         BUGSUM=0.0
         DO 18 II=1,N
   18       BUGSUM=BUGSUM+Q(J,II)
         IF (BUGSUM .EQ. 0.0) THEN
	    BUGFLG=1
            WRITE(12,20) J
   20       FORMAT(/'NONE OF YOUR SPECIES ARE IN ANALOG CORE ',I4)
            GOTO 24
         END IF
         DO 23 II=1,N
            Q(J,II)=Q(J,II)/BUGSUM
            IF ((CHOICE .EQ. 3) .AND. (Q(J,II) .NE. 0.0)) THEN
               SUMXX(II)=SUMXX(II)+Q(J,II)*Q(J,II)
               SUMX(II)=SUMX(II)+Q(J,II)
               NN(II)=NN(II)+1
            END IF
   23    CONTINUE
   24 CONTINUE
      IF (BUGFLG .EQ. 1) THEN
         WRITE(12,25)
   25    FORMAT(/'PLEASE CHECK YOUR INPUT.'/'***** HALT EXECUTION')
         GOTO 5000
      END IF
      IF (CHOICE .EQ. 3) THEN
         DO 27 J=1,N
            IF (NN(J) .NE. 0) XBAR(J)=SUMX(J)/NN(J)
            IF (NN(J) .EQ. 0) XBAR(J)=0.0
            IF (NN(J) .GT. 1)
     &       S(J)=SQRT((SUMXX(J)-NN(J)*XBAR(J)*XBAR(J))/(NN(J)-1))
            IF (NN(J) .LE. 1) THEN
               WRITE(12,26) J
   26          FORMAT(/'SPECIES ',I2,' HAS AN UNDEFINED STANDARD',
     &         ' DEVIATION.'/'PLEASE CHECK YOUR ANALOG INPUT FILE.'/
     &         '***** HALT EXECUTION')
               GOTO 5000
            END IF
   27    CONTINUE
      END IF
C /********************************************************************/
C /* WRITE OUT THE SPECIFICATIONS OF THE RUN, AND THE SPECIES NAMES,  */
C /* ALONG WITH THE TYPE OF DISSIMILARITY COEFFICIENT BEING USED.     */
C /********************************************************************/
      WRITE(12,31) INFO
   31 FORMAT(A80/)
      WRITE(12,32)
   32 FORMAT('YOU ARE USING THE FOLLOWING SPECIES:')
      WRITE(12,33) (NAMES(I),I=1,4)
   33 FORMAT(A80)
      WRITE(12,34)
   34 FORMAT(//'YOUR DISSIMILARITY COEFFICIENT IS:')
      IF (CHOICE .EQ. 1) WRITE(12,35)
   35 FORMAT('     SQUARED COSINE-THETA DISTANCE')
      IF (CHOICE .EQ. 2) WRITE(12,36)
   36 FORMAT('     SQUARED EUCLIDEAN DISTANCE')
      IF (CHOICE .EQ. 3) WRITE(12,37)
   37 FORMAT('     SQUARED STANDARDIZED EUCLIDEAN DISTANCE')
      IF (CHOICE .EQ. 4) WRITE(12,38)
   38 FORMAT('     SQUARED CHORD DISTANCE')
      IF ((CHOICE .LT. 1) .OR. (CHOICE .GT. 4)) THEN
         WRITE(12,39)
   39    FORMAT('YOU PICKED AN UNDEFINED DISSIMILARITY COEFFICIENT.'/
     &  'PLEASE CHECK THE CHOICE AND TRY AGAIN.'/'***** HALT EXECUTION')
         GOTO 5000
      END IF
C /********************************************************************/
C /* THIS IS THE MAIN LOOP OF THE PROGRAM.  INTERIOR SECTIONS OF THE  */
C /* CODE WILL BE EXPLAINED WITH BLOCK COMMENTS INSIDE THIS LOOP.     */
C /* LOOP THROUGH FOR EACH SUBJECT CORE AND THEN EACH ANALOG CORE.    */
C /* READ IN THE DATA FOR THE SUBJECT FAUNAL DATA.  (THE ANALOG DATA  */
C /* WAS READ IN ABOVE.)  THEN, INITIALIZE COUNTERS AND CONVERT THE   */
C /* SUBJECT DATA TO PROPORTION FORM AS WAS DONE FOR THE ANALOG DATA. */
C /* IF NO SPECIES ARE FOUND IN A GIVEN ANALOG CORE, A MESSAGE IS     */
C /* WRITTEN TO THE OUTPUT FILE AND EXECUTION IS TERMINATED.          */
C /********************************************************************/
      COUNT=1
      DO 1000 I=1,NCORE1
         IF (TAG1 .EQ. 0) READ(10,SFMT) CORE,(P(L),L=1,N)
         IF (TAG1 .EQ. 1) READ(10,SFMT) CORE,LAT,LON,DEPTH,(P(L),L=1,N)
         DO 46 M=1,4
            DO 45 MM=1,2
               MEAN(M,MM)=0.0
               SUMSQR(M,MM)=0.0
   45       CONTINUE
            SUMD(M)=0.0
            HI(M)=-9999.
            LO(M)=9999.
   46    CONTINUE
         LATSTD=0.0
         LATAVG=0.0
         LONSTD=0.0
         LONAVG=0.0
         BUGSUM=0.0
         DO 48 II=1,N
   48       BUGSUM=BUGSUM+P(II)
         IF (BUGSUM .EQ. 0.0) THEN
            WRITE(12,50) I
   50       FORMAT(/'THERE ARE NO SPECIES IN SUBJECT CORE ',I3,'.'/
     &       'PLEASE CHECK YOUR DATA.'/'***** EXECUTION TERMINATED')
            GOTO 5000
         END IF
         DO 54 II=1,N
   54       P(II)=P(II)/BUGSUM
         SUM(1)=0.0
         DO 55 K=1,N
   55       SUM(1)=SUM(1)+P(K)*P(K)
C /********************************************************************/
C /* CALCULATE THE DISSIMILARITY COEFFICIENTS FOR EACH CORE USING     */
C /* THE COEFFICIENT PICKED EARLIER BY THE USER.  NOTE THAT A CUT-OFF */
C /* POINT IS USED TO LOWER THE COST.  SHOULD A DISSIMILARITY VALUE   */
C /* BE TOO HIGH, THEN IT IS NOT INCLUDED IN THE ARRAY "DSML" WHICH   */
C /* IS USED TO SORT FOR THE BEST DISSIMILARITY VALUES.               */
C /********************************************************************/
         X=0
         DO 400 J=1,NCORE2
            SUM(2)=0.0
            D(J)=0.0
            DSML(J)=0.0
            F(J)=0
            DO 75 K=1,N
   75          SUM(2)=SUM(2)+Q(J,K)*Q(J,K)
            DO 200 K=1,N
               IF (CHOICE .EQ. 1)
     &          D(J)=D(J)+((P(K)/SQRT(SUM(1)))-(Q(J,K)/SQRT
     &          (SUM(2))))*((P(K)/SQRT(SUM(1)))-(Q(J,K)/SQRT(SUM(2))))
               IF (CHOICE .EQ. 2) D(J)=D(J)+(P(K)-Q(J,K))*(P(K)-Q(J,K))
               IF (CHOICE .EQ. 3)
     &          D(J)=D(J)+((P(K)-Q(J,K))/S(K))*((P(K)-Q(J,K))/S(K))
               IF (CHOICE .EQ. 4) D(J)=D(J)+(SQRT(P(K))-SQRT(Q(J,K)))*
     &          (SQRT(P(K))-SQRT(Q(J,K)))
  200       CONTINUE
            IF (((CHOICE .NE. 3) .AND. (D(J) .LE. 0.4)) .OR.
     &       ((CHOICE .EQ. 3) .AND. (D(J) .LE. 20.0))) THEN
               X=X+1
               DSML(X)=D(J)
               F(X)=J
            END IF
  400    CONTINUE
C /********************************************************************/
C /* WRITE OUT THE INPUT CORE INFORMATION (IN PERCENT FORM INSTEAD OF */
C /* PROPORTION FORM).  ALSO, SET UP THE HEADER FOR THE OUTPUT.       */
C /********************************************************************/
         DO 600 IJ=1,45
  600       PP(IJ)=P(IJ)*100.
         WRITE(12,601) COUNT
  601    FORMAT(/'********************* START OF SAMPLE NUMBER ',I4,
     &    ' *********************')
         WRITE(12,602)
  602    FORMAT('YOUR INPUT CORE (IN PERCENT FORM) IS:')
         IF (TAG1.EQ.0) WRITE(12,SFMT) CORE,(PP(MM),MM=1,N)
         IF (TAG1.EQ.1) WRITE(12,SFMT) CORE,LAT,LON,DEPTH,(PP(K),K=1,N)
         IF (X .EQ. 0) THEN
            WRITE(12,603)
  603       FORMAT('*** NO REASONABLE ANALOGS FOR THIS CORE ***')
            GOTO 999
         END IF
         IF (TAG2 .EQ. 0) THEN
            WRITE(12,605)
  605       FORMAT(/'THE TOP ANALOGS, ACCORDING TO THE DISSIMILARITY',
     &      ' VALUE, ARE:'//
     &     '   CORE                             ENV1   ENV2       DISS')
         ELSE
            WRITE(12,610)
  610       FORMAT(/'THE TOP ANALOGS, ACCORDING TO THE DISSIMILARITY',
     &       ' VALUE, ARE:'//
     &    '   CORE         LAT    LON     D     ENV1   ENV2       DISS')
         END IF
C /********************************************************************/
C /* SORT THE DISSIMILARITY COEFFICIENTS FROM LOW TO HIGH.  PASS      */
C /* THROUGH THE DATA EACH TIME AND FIND THE NEXT HIGHEST VALUE.  THE */
C /* FIRST TIME THROUGH, LOCATE THE LOWEST VALUE.  THE INNERMOST LOOP */
C /* CHECKS TO SEE IF THE DUPLICATE VALUE IS ONE OF THE SAME LINES    */
C /* ALREADY PROCESSED.  IF NOT, RANK THE DATA IN THE SORTED ARRAY.   */
C /********************************************************************/
         DO 615 L=1,NCORE2
  615       FLAG(L)=0
         HIGH=200000.0
         LOW=HIGH
         DO 750 J=1,TOP
            DO 700 JJ=1,X
               IF (J .EQ. 1) THEN
                  IF (DSML(JJ) .LT. LOW) THEN
                     LOW=DSML(JJ)
                     Z=JJ
                  END IF
               ELSE IF ((DSML(JJ).GE.LOW).AND.(DSML(JJ).LT.HIGH)) THEN
                  JLOOP=J-1
                  DO 650 L=1,JLOOP
                     IF (FLAG(L).EQ.JJ) GOTO 700
  650             CONTINUE
                  HIGH=DSML(JJ)
                  Z=JJ
               END IF
  700       CONTINUE
            IF (J .LE. X) THEN
               IF (TAG2 .EQ. 0) THEN
                  WRITE(12,702) COREID(F(Z)),T(1,F(Z)),T(2,F(Z)),DSML(Z)
  702             FORMAT(A12,21X,2(2X,F5.2),3X,F8.4)
               ELSE
                  XX(1)=INT(LAT2(1,F(Z)))
                  XX(2)=INT(LAT2(2,F(Z)))
                  XX(3)=INT(LONG2(1,F(Z)))
                  XX(4)=INT(LONG2(2,F(Z)))
                  WRITE(12,710) COREID(F(Z)),(XX(K),K=1,4),
     &             DEPTH2(F(Z)),(T(K,F(Z)),K=1,2),DSML(Z)
  710             FORMAT(A12,4I4,2X,I4,2(2X,F5.2),3X,F8.4)
               END IF
C /********************************************************************/
C /* CALCULATE THE MEAN, STANDARD DEVIATION, MAXIMUM, AND MINIMUM OF  */
C /* EACH COEFFICIENT, DEPTH (WHEN APPLICABLE), LATITUDE (WHEN        */
C /* APPLICABLE), AND THE ENVIRONMENTAL VARIABLES FOR THE EXISTING    */
C /* TOP-RANKED ANALOG CORES.  CALL SUBROUTINES "SUMUP" AND "STATS",  */
C /* EXCEPT FOR LATITIUDE WHERE NO MAX OR MIN IS CALCULATED.          */
C /********************************************************************/
               DO 720 IJ=1,45
  720             QQ(IJ)=Q(F(Z),IJ)
               IF ((CHOICE .EQ. 1) .OR. (CHOICE .EQ. 4))
     &          CALL SIMLAR(P,QQ,SIM(J),CHOICE,N)
               CALL SUMUP(MEAN(1,1),SUMSQR(1,1),MAXVAL(1),MINVAL(1),
     &          HI(1),LO(1),DSML(Z),MEAN(1,2),SUMSQR(1,2),SIM(J),
     &          SUMD(1),1)
               CALL SUMUP(MEAN(2,1),SUMSQR(2,1),MAXVAL(2),MINVAL(2),
     &          HI(2),LO(2),T(1,F(Z)),MEAN(2,2),SUMSQR(2,2),SIM(J),
     &          SUMD(2),2)
               CALL SUMUP(MEAN(3,1),SUMSQR(3,1),MAXVAL(3),MINVAL(3),
     &          HI(3),LO(3),T(2,F(Z)),MEAN(3,2),SUMSQR(3,2),SIM(J),
     &          SUMD(3),3)
               IF (TAG2 .EQ. 1) THEN
                  CALL SUMUP(MEAN(4,1),SUMSQR(4,1),MAXVAL(4),MINVAL(4),
     &             HI(4),LO(4),DEPTH2(F(Z))*1.,MEAN(4,2),SUMSQR(4,2),
     &             SIM(J),SUMD(4),4)
                  IF ((LAT2(1,F(Z)).LT.0.).AND.(LAT2(2,F(Z)).GT.0.))
     &             LAT2(2,F(Z))=-1.0*LAT2(2,F(Z))
                  IF ((LONG2(1,F(Z)).LT.0.).AND.(LONG2(2,F(Z)).GT.0.))
     &             LONG2(2,F(Z))=-1.0*LONG2(2,F(Z))
                  NLAT2=LAT2(1,F(Z))+(LAT2(2,F(Z))/60.0)
                  NLONG2=LONG2(1,F(Z))+(LONG2(2,F(Z))/60.0)
                  LONAVG=LONAVG+NLONG2
                  LATAVG=LATAVG+NLAT2
                  LATSTD=LATSTD+NLAT2*NLAT2
                  LONSTD=LONSTD+NLONG2*NLONG2
               END IF
               IF (J .LT. TOP) THEN
                  FLAG(J)=Z
                  IF (J .GT. 1) THEN
                     LOW=HIGH
                     HIGH=20000.0
                  END IF
                  GOTO 750
               END IF
               JX=J
            ELSE
               JX=J-1
            END IF
            MEND=3
            IF (TAG2 .EQ. 1) MEND=4
            DO 730 M=1,MEND
               CALL STATS(MEAN(M,1),SIGMA(M,1),SUMSQR(M,1),JX,MEAN(M,2),
     &          SIGMA(M,2),SUMSQR(M,2),SUMD(M),M,CHOICE)
  730       CONTINUE
            LATAVG=LATAVG/JX
            LONAVG=LONAVG/JX
            IF (JX .NE. 1) THEN
               LATSTD=SQRT((LATSTD-JX*LATAVG*LATAVG)/(JX-1))
               LONSTD=SQRT((LONSTD-JX*LONAVG*LONAVG)/(JX-1))
            ELSE
               LATSTD=0.0
               LONSTD=0.0
            END IF
            GOTO 775
  750    CONTINUE
C /********************************************************************/
C /* WRITE OUT THE MEAN, STANDARD DEVIATION, MINIMUM, AND MAXIMUM FOR */
C /* THE DISSIMILARITY COEFFICIENT PICKED EARLIER, AS WELL AS THE TWO */
C /* VARIABLES FROM THE ENVIRONMENTAL DATA FILE FOR THE TOP ANALOGS.  */
C /* ALSO, IF DEPTH AND LATITUDE ARE READ IN FROM THE ANALOG FILE,    */
C /* WRITE OUT THE RELATED STATISTICS.                                */
C /********************************************************************/
  775    WRITE(12,796)
  796    FORMAT(/'THE STATISTICS BELOW ARE FOR THE SORTED CORES:'/)
  798    WRITE(12,800)
  800    FORMAT('          MEAN      SIGMA     MIN       MAX      ',
     &    'W-MEAN    W-SIGMA')
         WRITE(12,850) MEAN(1,1),SIGMA(1,1),MINVAL(1),MAXVAL(1)
  850    FORMAT('DISS',2X,4F10.4,4X,'-----',5X,'-----')
         IF ((CHOICE.EQ.1) .OR. (CHOICE.EQ.4)) THEN
            IF (TAG2 .EQ. 1) WRITE(12,855) MEAN(4,1),
     &       SIGMA(4,1),MINVAL(4),MAXVAL(4),MEAN(4,2),SIGMA(4,2)
  855       FORMAT('DPTH',2X,6F10.4)
            WRITE(12,860) MEAN(2,1),SIGMA(2,1),
     &       MINVAL(2),MAXVAL(2),MEAN(2,2),SIGMA(2,2)
  860       FORMAT('ENV1',2X,6F10.4)
            WRITE(12,865) MEAN(3,1),SIGMA(3,1),
     &       MINVAL(3),MAXVAL(3),MEAN(3,2),SIGMA(3,2)
  865       FORMAT('ENV2',2X,6F10.4)
         ELSE
            IF (TAG2.EQ.1) WRITE(12,870)
     &       MEAN(4,1),SIGMA(4,1),MINVAL(4),MAXVAL(4)
  870        FORMAT('DPTH',2X,4F10.4,4X,'-----',5X,'-----')
            WRITE(12,875) MEAN(2,1),SIGMA(2,1),MINVAL(2),MAXVAL(2)
  875       FORMAT('ENV1',2X,4F10.4,4X,'-----',5X,'-----')
            WRITE(12,880) MEAN(3,1),SIGMA(3,1),MINVAL(3),MAXVAL(3)
  880       FORMAT('ENV2',2X,4F10.4,4X,'-----',5X,'-----')
         END IF
         IF (TAG2 .EQ. 1) THEN
            WRITE(12,885) LATAVG,LATSTD
  885       FORMAT('LAT ',2X,2F10.4,2(5X,'-----'),4X,'-----',5X,'-----')
            WRITE(12,890) LONAVG,LONSTD
  890       FORMAT('LONG',2X,2F10.4,2(5X,'-----'),4X,'-----',5X,'-----')
         END IF
C /********************************************************************/
C /* USING A SEPARATE OUTPUT FILE, WRITE OUT THE MEAN AND STANDARD    */
C /* DEVIATION FOR THE TOP ANALOGS TO EACH SUBJECT CORE.  THE OUTPUT  */
C /* DATA FILE WILL CONTAIN THE MEAN AND STANDARD DEVIATION OF THE    */
C /* DISSIMILARITY COEFFICIENT, DEPTH (WHEN READ IN), LATITUDE (WHEN  */
C /* READ IN), AND THE TWO ENVIRONMENTAL VARIABLES.  ALSO, A WEIGHTED */
C /* MEAN AND STANDARD DEVIATION ARE WRITTEN OUT WHEN APPLICABLE.     */
C /********************************************************************/
         IF (((CHOICE .EQ. 1).OR.(CHOICE .EQ. 4)).AND.(TAG2 .EQ. 0))
     &    WRITE(15,975) CORE,(MEAN(K,1),SIGMA(K,1),K=1,3),
     &    (MEAN(M,2),SIGMA(M,2),M=2,3)
  975     FORMAT(A12,2(1X,F8.4),4(1X,F5.2)/30X,4(1X,F5.2))
         IF (((CHOICE .EQ. 1).OR.(CHOICE .EQ. 4)).AND.(TAG2 .EQ. 1))
     &    WRITE(15,980) CORE,(MEAN(K,1),SIGMA(K,1),K=1,4),
     &    LATAVG,LATSTD,LONAVG,LONSTD,(MEAN(M,2),SIGMA(M,2),M=2,4)
  980     FORMAT(A12,2(1X,F8.4),4(1X,F5.2),2F8.2/
     &    2(F8.2,F7.2),4(1X,F5.2),2F8.2)
         IF (((CHOICE .EQ. 2).OR.(CHOICE .EQ. 3)).AND.(TAG2 .EQ. 0))
     &    WRITE(15,985) CORE,(MEAN(K,1),SIGMA(K,1),K=1,3)
  985     FORMAT(A12,2(1X,F8.4),4(1X,F5.2))
         IF (((CHOICE .EQ. 2).OR.(CHOICE .EQ. 3)).AND.(TAG2 .EQ. 1))
     &    WRITE(15,990) CORE,(MEAN(K,1),SIGMA(K,1),K=1,4),
     &    LATAVG,LATSTD,LONAVG,LONSTD
  990     FORMAT(A12,2(1X,F8.4),4(1X,F5.2),2F8.2/2(F8.2,F7.2))
  999     COUNT=COUNT+1
 1000 CONTINUE
      CLOSE(8)
      CLOSE(10)
      CLOSE(11)
      CLOSE(12)
      CLOSE(15)
      CLOSE(19)
      
      write(*,'(A)') " "
      write(*,'(A)') "ready" 
 5000 Write(*,'(A)') 'Press Return to continue...'
      Read (*,*) 
      STOP 
      END
      
      
      SUBROUTINE SUMUP(AVG1,SSQR1,MAXX,MINX,BIG,SML,X,AVG2,SSQR2,W,
     & SUMW,KK)
C /********************************************************************/
C /* THIS SUBROUTINE TAKES RUNNING SUMS THAT WILL BE USED FOR MEAN    */
C /* AND STANDARD DEVIATION.  ALSO, CALCULATE MAX AND MIN VALUES.     */
C /* THIS SUBROUTINE ALSO CALCULATES RUNNING SUMS FOR A WEIGHTED MEAN */
C /* AND STANDARD DEVIATION FOR THE ENVIRONMENTAL DATA.               */
C /********************************************************************/
      REAL AVG1,SSQR1,MAXX,MINX,BIG,SML,X,AVG2,SSQR2,W,SUMW
      AVG1=AVG1+X
      SSQR1=SSQR1+X*X
      MAXX=AMAX1(X,BIG)
      BIG=MAXX
      MINX=AMIN1(X,SML)
      SML=MINX
      IF (KK .NE. 1) THEN
         AVG2=AVG2+X*W
         SSQR2=SSQR2+X*X*W
         SUMW=SUMW+W
      END IF
      RETURN
      END
      SUBROUTINE STATS(AVG1,DEV1,SSQR1,N,AVG2,DEV2,SSQR2,WSUM,KK,CHOICE)
C /********************************************************************/
C /* THIS SUBROUTINE CALCULATES MEAN AND STANDARD DEVIATION.          */
C /********************************************************************/
      REAL AVG1,DEV1,SSQR1,DEV2,SSQR2,AVG2,WSUM
      INTEGER CHOICE
      AVG1=AVG1/N
      IF (N .NE. 1) THEN
         DEV1=SQRT((SSQR1-N*AVG1*AVG1)/(N-1))
      ELSE
         DEV1=0.0
      END IF
      IF ((CHOICE .EQ. 1) .OR. (CHOICE .EQ. 4)) THEN
         IF (KK .NE. 1) AVG2=AVG2/WSUM
         IF (N .EQ. 1) DEV2=0.00
         IF ((KK .NE. 1) .AND. (N .NE. 0))
     &      DEV2=SQRT((SSQR2-AVG2*AVG2*WSUM)/(N-1))
      END IF
      RETURN
      END
      SUBROUTINE SIMLAR(P,Q,SIM,CHOICE,N)
C /********************************************************************/
C /* THIS SUBROUTINE CALCULATES SIMILARITY COEFFICIENTS FOR THE TOP   */
C /* 10 ANALOGS ONLY WHEN THE USER CHOOSES COSINE-THETA OR CHORD AS   */
C /* THE COEFFICIENT.  THESE VALUES ARE USED IN WEIGHTED AVERAGES.    */
C /********************************************************************/
      REAL SIM,P(45),Q(45),SUM1,SUM2
      INTEGER CHOICE
      SUM1=0.0
      SUM2=0.0
      SIM=0.0
      DO 6000 K=1,N
         SUM1=SUM1+P(K)*P(K)
         SUM2=SUM2+Q(K)*Q(K)
 6000 CONTINUE
      DO 7000 K=1,N
         IF (CHOICE .EQ. 1) SIM=SIM+(P(K)*Q(K))/(SQRT(SUM1)*SQRT(SUM2))
         IF (CHOICE .EQ. 4) SIM=SIM+SQRT(P(K)*Q(K))
 7000 CONTINUE
      RETURN
      END

